QrResponse class
Constructors
- QrResponse({String? qrPath, String? bitcoinAddress, String? transactionId, String? qrdata, double? bitcoinAmount})
-
QrResponse.fromJson(Map<
String, dynamic> json)
Properties
- bitcoinAddress ↔ String?
-
getter/setter pair
- bitcoinAmount ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- qrdata ↔ String?
-
getter/setter pair
- qrPath ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionId ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited